@@ -174,9 +174,8 @@ class Filter(repops.MultiOpRep):
             mode = "pos"
         else:
             mode = "dim"
-
         nslices = self._apply(source._slices,cslice,seldimpath,mode)
-
+       
         return self._initialize(tuple(nslices))
 
     @classmethod
@@ -192,6 +191,9 @@ class Filter(repops.MultiOpRep):
         else:
             assert seldimpath, "Filter dimpath is empty"
 
+            #if(cslice.dims and isinstance(cslice.type,rtypes.TypeInteger)):
+            #    cslice = ops.PackArrayOp(cslice)
+
             if(isinstance(cslice.type, rtypes.TypeInteger)):
                 ndim = None
             elif(isinstance(cslice.type, rtypes.TypeArray)):
@@ -324,7 +326,7 @@ class Join(repops.MultiOpRep):
 
 
 class Match(repops.MultiOpRep):
-    def __init__(self, lsource, rsource, lslice=None, rslice=None, jointype="inner", merge_same=False):
+    def __init__(self, lsource, rsource, lslice=None, rslice=None, jointype="inner", merge_same=False, mode="dim"):
         assert jointype in set(["inner","left","right","full"]), "Jointype should be inner, left, right or full"
         assert (not isinstance(lslice,representor.Representor)), "Representor objects not allowed as lslice. Use context, string or int to indicate slice in lsource"
         assert (not isinstance(rslice,representor.Representor)), "Representor objects not allowed as rslice. Use context, string or int to indicate slice in rsource"
@@ -337,9 +339,9 @@ class Match(repops.MultiOpRep):
         if not lslice is None:
             lslice = lsource.Get(lslice)
             
-        repops.MultiOpRep.__init__(self,(lsource,rsource,lslice,rslice),jointype=jointype, merge_same=merge_same)
+        repops.MultiOpRep.__init__(self,(lsource,rsource,lslice,rslice),jointype=jointype, merge_same=merge_same,mode=mode)
 
-    def _process(self, sources, jointype, merge_same):
+    def _process(self, sources, jointype, merge_same,mode):
         lsource, rsource, lslice,rslice = sources
         if not lsource._slicesKnown() or not rsource._slicesKnown():
             return
@@ -362,20 +364,31 @@ class Match(repops.MultiOpRep):
             return
         lslice = lslice._slices[0]
         rslice = rslice._slices[0]
-        nslices = self._apply(lsource, rsource, lslice, rslice, jointype, merge_same)
+        nslices = self._apply(lsource, rsource, lslice, rslice, jointype, merge_same, mode)
         return self._initialize(tuple(nslices))
    
     @classmethod
-    def _apply(cls,lsource, rsource, lslice,rslice, jointype="inner", merge_same=False):
-        lindex,rindex = ops.EquiJoinIndexOp(lslice,rslice, jointype=jointype).results
+    def _apply(cls,lsource, rsource, lslice,rslice, jointype="inner", merge_same=False, mode="dim"):
+        lslice = ops.ensure_frozen(lslice)
+        rslice = ops.ensure_frozen(rslice)
+
+        leftslice = ops.PackArrayOp(lslice)
+        rightslice = ops.PackArrayOp(rslice)
+       
+        ((bleftslice,brightslice),(leftplan,rightplan))= ops.broadcast((leftslice,rightslice),mode=mode)
+
+        lindex,rindex = ops.EquiJoinIndexOp(bleftslice,brightslice, jointype=jointype, mode=mode).results
 
         lslices = list(lsource._slices)
         rslices = list(rsource._slices)
         if(lslice.name == rslice.name and jointype=="inner" and lslice in lslices and rslice in rslices):
             rslices.pop(rslices.index(rslice))
 
-        lslices = list(Filter._apply(lslices, lindex, lslice.dims, "dim"))
-        rslices = list(Filter._apply(rslices, rindex, rslice.dims, "dim"))
+        lslices = [ops.broadcastParentsFromPlan(tslice, lslice.dims[-1:], leftplan, leftslice.dims, bleftslice.dims, [rightslice], True) for tslice in lslices]
+        rslices = [ops.broadcastParentsFromPlan(tslice, rslice.dims[-1:], rightplan, rightslice.dims, brightslice.dims, [leftslice], True) for tslice in rslices]
+
+        lslices = list(Filter._apply(lslices, lindex, lslice.dims[-1:], "dim"))
+        rslices = list(Filter._apply(rslices, rindex, rslice.dims[-1:], "dim"))
         if merge_same:
             lnames = [lslice.name for lslice in lslices]
             for rslice in list(rslices):
@@ -407,9 +420,28 @@ class Replace(repops.MultiOpRep):
 
         nslices = list(Match._apply(source, translator, slice, translator._slices[0],"inner"))
         nslices[slicepos] = ops.ChangeNameOp(nslices[-1],slice.name)
-        nslices = nslices[:-2]
+        remove = (len(source._slices) + len(translator._slices)) -len(nslices) - len(translator._slices)
+        nslices = nslices[:remove]
         return self._initialize(tuple(nslices))
 
+
+class Take(repops.MultiOpRep):
+    def __init__(self, source, take_source, allow_missing=False):
+        repops.MultiOpRep.__init__(self,(source, take_source), allow_missing = allow_missing)
+   
+    def _sprocess(self, sources, allow_missing):
+        source, take_source = sources
+        if len(source._slices) == 2:
+            source = source.IndexDict()
+        assert len(source._slices) == 1, "Take source should have one slice"
+        source_slice = source._slices[0]
+
+        nslices = []
+        for take_slice in take_source._slices:
+            nslices.append(ops.TakeOp(source_slice, take_slice, allow_missing))
+        return self._initialize(tuple(nslices))
+
+
 class Stack(repops.MultiOpRep):
     def __init__(self, *sources, **kwargs):
         repops.MultiOpRep.__init__(self,sources, **kwargs)
