@@ -285,10 +285,10 @@ class Representor(Node):
             if(isinstance(cond,NewDim)):
                 self = repops_dim.InsertDim(self,pos + ipos, cond.name)
             elif(cond is Ellipsis):
-                ulength = len(dimpaths.uniqueDimPath([s.dims for s in self._slices]))
+                ulength = len(dimpaths.uniqueDimPath([s.dims for s in self._slices], only_unique=True))
                 rem_length = len([c for c in condition[(pos + 1):] if not isinstance(cond,NewDim)])
                 newnextpos = ulength - rem_length
-                curnextpos = pos + ipos + 1
+                curnextpos = pos + ipos
                 ipos += newnextpos - curnextpos #skip some dims
         
         #next, perform filtering in backwards order
@@ -621,6 +621,8 @@ class Representor(Node):
     def Replace(self, slice, translator, fromslice=0, toslice=1):
         return repops_multi.Replace(self, slice, translator, fromslice, toslice) 
 
+    def ReplaceMissing(self, def_value=NOVAL):
+        return repops_funcs.ReplaceMissing(self, def_value=def_value)
 
     def Merge(self, other):
         return repops_funcs.Merge(self, other)
@@ -707,7 +709,10 @@ class Representor(Node):
     
     def Median(self, dim=None):
         return repops_funcs.Median(self, dim)
-      
+    
+    def Std(self, dim=None):
+        return repops_funcs.Std(self, dim)
+     
     def Any(self,dim=None):
         return repops_funcs.Any(self,dim)
 
@@ -750,6 +755,13 @@ class Representor(Node):
     def Dict(self, with_missing=False):
         """Combines slices into a tuple type"""
         return repops_slice.Dict(self, with_missing=with_missing)
+    
+    def IndexDict(self):
+        """Combines slices into a tuple type"""
+        return repops_slice.IndexDict(self)
+
+    def TakeFrom(self, other, allow_missing=False):
+        return repops_multi.Take(other, self, allow_missing)
 
     def ToPython(self):
         """Converts data into python data structure"""
@@ -794,7 +806,8 @@ class Representor(Node):
         return repops_slice.To(self, *slices, **kwargs)
               
               
-
+    def AddSlice(self, name, data, dtype=None):
+        return repops_slice.AddSlice(self, data, name, dtype)
 
 
     def Get(self, *slices, **kwds):
